ChannelAddr

Enum ChannelAddr 

pub enum ChannelAddr {
    Tcp(SocketAddr),
    MetaTls(TlsAddr),
    Tls(TlsAddr),
    Quic(TlsAddr),
    MetaQuic(TlsAddr),
    Local(u64),
    Unix(SocketAddr),
    Alias {
        dial_to: Box<ChannelAddr>,
        bind_to: Box<ChannelAddr>,
    },
}
The type of a channel address, used to multiplex different underlying channel implementations. ChannelAddrs also have a concrete syntax: the address type (e.g., “tcp” or “local”), followed by “:”, and an address parseable to that type. For example:

  • tcp:127.0.0.1:1234 - localhost port 1234 over TCP
  • tcp:192.168.0.1:1111 - 192.168.0.1 port 1111 over TCP
  • quic:example.com:1234 - example.com port 1234 over QUIC
  • local:123 - the (in-process) local port 123
  • unix:/some/path - the Unix socket at /some/path

Both local and TCP ports 0 are reserved to indicate “any available port” when serving.

let addr: ChannelAddr = "tcp:127.0.0.1:1234".parse().unwrap();
let ChannelAddr::Tcp(socket_addr) = addr else {
    panic!()
};
assert_eq!(socket_addr.port(), 1234);
assert_eq!(socket_addr.is_ipv4(), true);

Variants



Tcp(SocketAddr)

A socket address used to establish TCP channels. Supports both IPv4 and IPv6 address / port pairs.



MetaTls(TlsAddr)

An address to establish TCP channels with TLS support within Meta. Uses TlsAddr with hostname and port.



Tls(TlsAddr)

An address to establish TCP channels with configurable TLS support. Uses TlsAddr with hostname and port.



Quic(TlsAddr)

An address to establish QUIC channels with configurable TLS support. Uses TlsAddr with hostname and port.



MetaQuic(TlsAddr)

An address to establish QUIC channels with TLS support within Meta. Uses TlsAddr with hostname and port.



Local(u64)

Local addresses are registered in-process and given an integral index.



Unix(SocketAddr)

A unix domain socket address. Supports both absolute path names as well as “abstract” names per https://manpages.debian.org/unstable/manpages/unix.7.en.html#Abstract_sockets



Alias

A pair of addresses, one for the client and one for the server:

  • The client should dial to the dial_to address.
  • The server should bind to the bind_to address.

The user is responsible for ensuring the traffic to the dial_to address is routed to the bind_to address.

This is useful for scenarios where the network is configured in a way, that the bound address is not directly accessible from the client.

For example, in AWS, the client could be provided with the public IP address, yet the server is bound to a private IP address or simply INADDR_ANY. Traffic to the public IP address is mapped to the private IP address through network address translation (NAT).

Alias is serve-side syntax. serve consumes it by binding to bind_to and advertising dial_to; identity-bearing values such as proc addresses, actor addresses, host references, and routing keys should store only dial_to. Dial helpers canonicalize aliases the same way.

Fields

dial_to: Box<ChannelAddr>

The address to which the client should dial to.

bind_to: Box<ChannelAddr>

The address to which the server should bind to.

Implementations

Source

impl ChannelAddr

pub fn any(transport: ChannelTransport) -> Self

The “any” address for the given transport type. This is used to servers to “any” address.

pub fn transport(&self) -> ChannelTransport

The transport used by this address.

Source

impl ChannelAddr

pub fn into_dial_addr(self) -> Self

Return the canonical address that remote peers should dial.

For regular addresses this is the address itself. For aliases, this recursively consumes the alias and returns its dial_to address. Use this before storing an address in identity-bearing state; aliases are intended as input to serve.

pub fn from_zmq_url(address: &str) -> Result<Self, Error>

Parse ZMQ-style URL format: scheme://address Supports:

  • tcp://hostname:port or tcp://*:port (wildcard binding)
  • inproc://endpoint-name (equivalent to local)
  • ipc://path (equivalent to unix)
  • metatls://hostname:port or metatls://*:port
  • quic://hostname:port or quic://*:port
  • metaquic://hostname:port or metaquic://*:port
  • Alias format: dial_to_url@bind_to_url (e.g., tcp://host:port@tcp://host:port) Note: Alias format is currently only supported for TCP addresses

Alias format is meant for serving. Callers that will dial or store the result as an identity should canonicalize it with ChannelAddr::into_dial_addr.

pub fn from_zmq_url_with_listener( address: &str, ) -> Result<(Self, Option<TcpListener>), Error>

Parse ZMQ-style URL format, with support for pre-opened file descriptors.

When the port portion of a URL is fdNNN (e.g. tcp://myhost:fd5), the file descriptor is adopted as a pre-bound TcpListener. The returned ChannelAddr will contain the real port that the fd is bound to, and the Option<TcpListener> will be Some.

Safety

When using the fd syntax, the caller must ensure the file descriptor is a valid, bound TCP socket that is not used elsewhere. The socket does not need to be in a listening state — listen() will be called automatically.

pub fn to_zmq_url(&self) -> String

Render as a ZMQ-style URL, the inverse of from_zmq_url.