pub enum ServerError {
Io(ChannelAddr, Error),
Listen(ChannelAddr, Error),
Resolve(ChannelAddr, Error),
Internal(ChannelAddr, Error),
}Expand description
Error returned during server operations.
Variants
Io(ChannelAddr, Error)
An I/O error occurred while operating on the server at the given address.
Listen(ChannelAddr, Error)
Listening on the given address failed.
Resolve(ChannelAddr, Error)
Resolving the given address failed.
Internal(ChannelAddr, Error)
An internal server error occurred for the given address.